@@ -30,3 +30,7 @@ class CommandType(Enum):
     SetInstanceField = 25
     InvokeGenericStaticMethod = 26
     InvokeGenericMethod = 27
+    CreateGenericClassInstance = 28
+    GetEnumItem = 29
+    GetEnumName = 30
+    GetEnumValue = 31
