@@ -12,8 +12,10 @@ class SetStaticFieldHandler(AbstractCommandHandler):
                 raise Exception("SetStaticFieldHandler parameters mismatch!")
 
             clazz = command.payload[0]
-            setattr(clazz, command.payload[1], command.payload[2])
-            return "SetStaticFieldHandler - success"
+            field = command.payload[1]
+            new_value = command.payload[2]
+            setattr(clazz, field, new_value)
+            return 0
         except Exception as e:
             exc_type, exc_value = type(e), e
             new_exc = exc_type(exc_value).with_traceback(e.__traceback__)
