@@ -3,6 +3,7 @@ use strict;
 use warnings FATAL => 'all';
 use Moose;
 use lib 'lib';
+use aliased 'Javonet::Core::Handler::CommandHandler::ValueHandler' => 'ValueHandler';
 use aliased 'Javonet::Core::Handler::CommandHandler::LoadLibraryHandler' => 'LoadLibraryHandler';
 use aliased 'Javonet::Core::Handler::CommandHandler::GetStaticFieldHandler' => 'GetStaticFieldHandler';
 use aliased 'Javonet::Core::Handler::CommandHandler::SetStaticFieldHandler' => 'SetStaticFieldHandler';
@@ -30,6 +31,7 @@ use aliased 'Javonet::Core::Handler::AbstractHandler' => 'AbstractHandler';
 use aliased 'Javonet::Sdk::Core::RuntimeLib' => 'RuntimeLib', qw(get_runtime);
 use aliased 'Javonet::Core::Handler::HandlerDictionary' => 'HandlerDictionary', qw(get_handler);
 
+my $value_handler = ValueHandler->new();
 my $load_library_handler = LoadLibraryHandler->new();
 my $get_static_field_handler = GetStaticFieldHandler->new();
 my $set_static_field_handler = SetStaticFieldHandler->new();
@@ -48,6 +50,10 @@ my $array_get_rank_handler = ArrayGetRankHandler->new();
 my $array_set_item_handler = ArraySetItemHandler->new();
 
 
+Javonet::Core::Handler::HandlerDictionary::add_handler_to_dict(
+    Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
+    $value_handler
+);
 Javonet::Core::Handler::HandlerDictionary::add_handler_to_dict(
     Javonet::Sdk::Core::PerlCommandType::get_command_type('LoadLibrary'),
     $load_library_handler
@@ -120,7 +126,7 @@ sub handle_command {
     if (ref $response eq '') {
         return PerlCommand->new(
             runtime      => Javonet::Sdk::Core::RuntimeLib::get_runtime('Perl'),
-            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Response'),
+            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
             payload      => [ $response ]
         )
     }
