@@ -7,7 +7,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(get_command_type);
 
 my %command_type = (
-    'Value'                  => 0,
+    'Value'                     => 0,
     'LoadLibrary'               => 1,
     'InvokeStaticMethod'        => 2,
     'GetStaticField'            => 3,
@@ -35,6 +35,10 @@ my %command_type = (
     'SetInstanceField'          => 25,
     'InvokeGenericStaticMethod' => 26,
     'InvokeGenericMethod'       => 27,
+    'CreateGenericClassInstance'=> 28,
+    'GetEnumItem'               => 29,
+    'GetEnumName'               => 30,
+    'GetEnumValue'              => 31,
 
 
 );
