@@ -111,6 +111,7 @@ sub get_type {
     );
 }
 
+#@override
 sub cast {
     my $self = shift;
     my @arguments = @_;
@@ -130,6 +131,26 @@ sub cast {
     );
 }
 
+#@override
+sub get_enum_item {
+    my $self = shift;
+    my @arguments = @_;
+
+    my $command = PerlCommand->new(
+        runtime => $self->{runtime_lib},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetEnumItem'),
+        payload => \@arguments
+    );
+
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_lib},
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
 
 sub build_command {
     my ($self, $command) = @_;
